[Asterisk-code-review] testsuite: Increase the startup core fully booted timeout time. (testsuite[master])

Richard Mudgett asteriskteam at digium.com
Thu Dec 1 13:36:35 CST 2016


Richard Mudgett has uploaded a new change for review. ( https://gerrit.asterisk.org/4545 )

Change subject: testsuite: Increase the startup core fully booted timeout time.
......................................................................

testsuite: Increase the startup core fully booted timeout time.

Using the new compiler address sanitizer features can slow down Asterisk
startup so much that the test aborts before Asterisk gets booted.

ASTERISK-26527

Change-Id: I40839ba09ea4888cf337ec9ee6e19b7e9bb7c725
---
M asttest/lib/lua/astlib.lua
M lib/python/asterisk/asterisk.py
2 files changed, 5 insertions(+), 5 deletions(-)


  git pull ssh://gerrit.asterisk.org:29418/testsuite refs/changes/45/4545/1

diff --git a/lib/python/asterisk/asterisk.py b/lib/python/asterisk/asterisk.py
index bfde74f..994aa5d 100755
--- a/lib/python/asterisk/asterisk.py
+++ b/lib/python/asterisk/asterisk.py
@@ -490,7 +490,7 @@
         def __wait_fully_booted_error(cli_command):
             """Errback for CLI command waitfullybooted"""
 
-            timeout = 90 if self.valgrind_enabled else 5
+            timeout = 90 if self.valgrind_enabled else 45
             if time.time() - self.__start_asterisk_time > timeout:
                 msg = "Asterisk core waitfullybooted for %s failed" % self.host
                 LOGGER.error(msg)

diff --git a/asttest/lib/lua/astlib.lua b/asttest/lib/lua/astlib.lua
index 203e656..2562c5e 100644
--- a/asttest/lib/lua/astlib.lua
+++ b/asttest/lib/lua/astlib.lua
@@ -118,12 +118,12 @@
 function asterisk:_waitfullybooted()
 	-- wait for asterisk to be fully booted.  We do this by reading the
 	-- output of the 'core waitfullybooted' command and looking for the
 	-- string 'fully booted'.  We will try 10 times before completely
 	-- giving up with a 500 ms delay in between each try.  This is
 	-- necessary to give asterisk time to start the CLI socket.
 	local booted
 	local output = ""
-	for _=1,10 do
+	for _=1,45 do
 		local err
 		booted, err = self:cli("core waitfullybooted")
 		
@@ -141,7 +141,7 @@
 			output = output .. err
 		end
 
-		posix.usleep(500000)
+		posix.usleep(1000000)
 	end
 	if booted and not booted:find("fully booted") then
 		print("error waiting for asterisk to fully boot: " .. booted)
@@ -118,12 +118,12 @@
 	-- wait for asterisk to be fully booted.  We do this by reading the
 	-- output of the 'core waitfullybooted' command and looking for the
-	-- string 'fully booted'.  We will try 10 times before completely
-	-- giving up with a 500 ms delay in between each try.  This is
+	-- string 'fully booted'.  We will try 45 times before completely
+	-- giving up with a 1000 ms delay in between each try.  This is
 	-- necessary to give asterisk time to start the CLI socket.
 	local booted
-- 
To view, visit https://gerrit.asterisk.org/4545
To unsubscribe, visit https://gerrit.asterisk.org/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I40839ba09ea4888cf337ec9ee6e19b7e9bb7c725
Gerrit-PatchSet: 1
Gerrit-Project: testsuite
Gerrit-Branch: master
Gerrit-Owner: Richard Mudgett <rmudgett at digium.com>



More information about the asterisk-code-review mailing list